@@ -18,7 +18,7 @@ local SetRpgStyle = function(eventAf)
 	eventAf:GetChild("HeaderBorder"):diffuse(RpgYellow)
 	
 	local idx = SL.Global.ActiveColorIndex
-	local faction_name = SL.SRPG8.GetFactionName(idx)
+	local faction_name = SL.SRPG9.GetFactionName(idx)
 
 	if faction_name == "Stamina Nation" then
 		eventAf:GetChild("HeaderBackground")
@@ -195,6 +195,8 @@ local SetLeaderboardData = function(eventAf, leaderboardData, event)
 end
 
 local GetRpgPaneFunctions = function(eventAf, rpgData, player)
+	local pn = ToEnumShortString(player)
+	
 	local score, scoreDelta, rate, rateDelta = 0, 0, 0, 0
 	local pss = STATSMAN:GetCurStageStats():GetPlayerStageStats(player)
 	local paneTexts = {}
@@ -265,6 +267,25 @@ local GetRpgPaneFunctions = function(eventAf, rpgData, player)
 			end
 		end
 	end
+	
+	-- Also pass the response data to the progress box.
+	local progressBox = SCREENMAN:GetTopScreen()
+			:GetChild("Overlay")
+			:GetChild("ScreenEval Common")
+			:GetChild(pn.."_AF_Upper")
+			:GetChild("EventProgress"..pn)
+	if progressBox ~= nil then
+		progressBox:playcommand("SetData",{
+			rpgData = {
+				["name"] = rpgData["name"],
+				["score"] = score,
+				["scoreDelta"] = scoreDelta,
+				["rate"] = rate,
+				["rateDelta"] = rateDelta,
+				["statImprovements"] = progress["statImprovements"],
+			},
+		})
+	end
 
 	table.insert(paneTexts, string.format(
 		"Skill Improvements\n\n"..
@@ -832,7 +853,7 @@ for player in ivalues(PlayerNumber) do
 		-- Main Black cement background
 		Def.Sprite {
 			Name="BackgroundImage",
-			Texture=THEME:GetPathG("", "_VisualStyles/SRPG8/Overlay-BG.jpg"),
+			Texture=THEME:GetPathG("", "_VisualStyles/SRPG9/Overlay-BG.png"),
 			InitCommand=function(self)
 				self:CropTo(paneWidth, paneHeight)
 			end
