@@ -76,17 +76,27 @@ local af = Def.ActorFrame{
 
   LoadFont("Common Normal")..{
     Text=THEME:GetString("ScreenSelectProfile", "LoginInstructions"),
-    InitCommand=function(self) self:y(-150) end,
+    InitCommand=function(self)
+      self:y(-150)
+      if ThemePrefs.Get("RainbowMode") then
+        self:diffuse(Color.Black)
+      end
+    end,
   },
   LoadFont("Common Normal")..{
     Text=THEME:GetString("ScreenSelectProfile", "VisitWebsite"),
-    InitCommand=function(self) self:y(-120) end,
+    InitCommand=function(self)
+      self:y(-120)
+      if ThemePrefs.Get("RainbowMode") then
+        self:diffuse(Color.Black)
+      end
+    end,
   },
 
-  LoadFont("Common Normal")..{
+  LoadFont("Common Bold")..{
     Text=THEME:GetString("ScreenEvaluation", "PressStartToContinue"),
     InitCommand=function(self)
-      self:y(150)
+      self:zoom(0.55):y(150):shadowlength(1)
     end,
   },
 }
@@ -113,6 +123,11 @@ for player in ivalues(GAMESTATE:GetHumanPlayers()) do
 
     LoadFont("Common Normal")..{
       Text=SL[pn].ApiKey and THEME:GetString("ScreenSelectProfile", "ProfileConnected") or "",
+      InitCommand=function(self)
+        if ThemePrefs.RainbowMode then
+          self:diffuse(Color.Black)
+        end
+      end,
       HideQrMessageCommand=function(self, params)
         if params.pn == pn then
           WriteGrooveStatsIni(player)
