@@ -398,10 +398,6 @@ local Overrides = {
 				return { "ShowFaPlusWindow" }
 			end
 
-			if SL.Global.GameMode == "FA+" then
-				return { "ShowExScore" }
-			end
-
 			return { "ShowFaPlusWindow", "ShowExScore", "ShowFaPlusPane" }
 		end,
 		LoadSelections = function(self, list, pn)
@@ -411,11 +407,6 @@ local Overrides = {
 				return list
 			end
 
-			if SL.Global.GameMode == "FA+" then
-				list[1] = mods.ShowExScore or false
-				return list
-			end		
-
 			list[1] = mods.ShowFaPlusWindow or false
 			list[2] = mods.ShowExScore or false
 			list[3] = mods.ShowFaPlusPane and true
@@ -434,15 +425,6 @@ local Overrides = {
 				return
 			end
 
-			if SL.Global.GameMode == "FA+" then
-				-- always disable in FA+ mode since it's handled engine side.
-				mods.ShowFaPlusWindow = false
-				mods.ShowExScore = list[1]
-				-- the main score pane is already the FA+ pane
-				mods.ShowFaPlusPane = false
-				return
-			end
-
 			mods.ShowFaPlusWindow = list[1]
 			mods.ShowExScore = list[2]
 			mods.ShowFaPlusPane = list[3]
